"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.highlightNodeContent = void 0;
var highlightText_1 = require("./highlightText");
/**
 * Mutate a `node` by highlighting and setting its `textContent` property.
 * @private
 */
var mutateNode = function (node, words) {
    // We only want to highlight text nodes, so recursively find those nodes.
    if (node.childNodes.length > 0) {
        Array.from(node.childNodes).forEach(function (childNode) {
            return mutateNode(childNode, words);
        });
    }
    if (node.nodeType === 3) {
        // eslint-disable-next-line no-param-reassign
        node.textContent = highlightText_1.highlightText(node.textContent || '', words);
    }
};
/**
 * Highlight content in a `node`.
 */
var highlightNodeContent = function (node, words) {
    var subject = node.cloneNode(true);
    // Highlight content in the node by mutating it.
    mutateNode(subject, words);
    return subject;
};
exports.highlightNodeContent = highlightNodeContent;
